@@ -134,6 +134,9 @@ INVALIDPARAMETERVALUE_EMAILCONTENTISWRONG = 'InvalidParameterValue.EmailContentI
 # 邮件地址不合法，请检查邮件地址格式。
 INVALIDPARAMETERVALUE_ILLEGALEMAILADDRESS = 'InvalidParameterValue.IllegalEmailAddress'
 
+# 发信人别名错误。
+INVALIDPARAMETERVALUE_ILLEGALSENDERNAME = 'InvalidParameterValue.IllegalSenderName'
+
 # 收件人地址附带的模板参数不能包含html标签。
 INVALIDPARAMETERVALUE_INVALIDTEMPLATEDATA = 'InvalidParameterValue.InValidTemplateData'
 
@@ -149,6 +152,9 @@ INVALIDPARAMETERVALUE_NOTEXISTDOMAIN = 'InvalidParameterValue.NotExistDomain'
 # 收件人列表描述不合法，描述不可包含特殊字符，字符长度范围:1~300。
 INVALIDPARAMETERVALUE_RECEIVERDESCILLEGAL = 'InvalidParameterValue.ReceiverDescIllegal'
 
+# 收件人地址错误。
+INVALIDPARAMETERVALUE_RECEIVEREMAILINVALID = 'InvalidParameterValue.ReceiverEmailInvalid'
+
 # 收件人列表名字不合法，请检查字符内容及大小。
 INVALIDPARAMETERVALUE_RECEIVERNAMEILLEGAL = 'InvalidParameterValue.ReceiverNameIllegal'
 
@@ -173,7 +179,7 @@ INVALIDPARAMETERVALUE_TEMPLATECONTENTISWRONG = 'InvalidParameterValue.TemplateCo
 # 模板参数必须为json格式。
 INVALIDPARAMETERVALUE_TEMPLATEDATAERROR = 'InvalidParameterValue.TemplateDataError'
 
-# 收件人地址附带的模板参数长度超过限制
+# 单条收件人地址附带的模板参数(整个 JSON 结构)， 长度超过限制 800 bytes
 INVALIDPARAMETERVALUE_TEMPLATEDATALENLIMIT = 'InvalidParameterValue.TemplateDataLenLimit'
 
 # 模板名字不合法，请检查字符内容及大小。
@@ -194,7 +200,7 @@ INVALIDPARAMETERVALUE_WRONGDATE = 'InvalidParameterValue.WrongDate'
 # 超过配额限制。
 LIMITEXCEEDED = 'LimitExceeded'
 
-# 收件人地址数量超过限制。
+# 收件人个数限制20000个以内。
 LIMITEXCEEDED_EXCEEDRECEIVERDETAILLIMIT = 'LimitExceeded.ExceedReceiverDetailLimit'
 
 # 收件人列表数量超过限制。
@@ -230,7 +236,7 @@ OPERATIONDENIED_EXCEEDDOMAINLIMIT = 'OperationDenied.ExceedDomainLimit'
 # 超出最大发信地址限制。
 OPERATIONDENIED_EXCEEDSENDERLIMIT = 'OperationDenied.ExceedSenderLimit'
 
-# 收件人列表正在被操作，请稍后操作。
+# 收件人列表正在上传中，请稍后操作。
 OPERATIONDENIED_RECEIVERISOPERATING = 'OperationDenied.ReceiverIsOperating'
 
 # 收件人列表不存在。
